==> ssp-center-api-0.7.55-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteMediaAppBackendService.java <==
/**
 * Project Name:media-api File Name:RemoteMediaAppService.java Package Name:cn.com.duiba.tuia.media.api.remoteservice
 * Date:2016年9月30日下午3:48:58 Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 */

package cn.com.duiba.tuia.ssp.center.api.remote;

import java.util.List;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.*;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName:RemoteMediaAppService <br/>
 * Function: tuia媒体app信息服务. <br/>
 * Date: 2016年9月30日 下午3:48:58 <br/>
 * 
 * @author guyan
 * @version
 * @since JDK 1.6
 * @see
 */
@AdvancedFeignClient
public interface RemoteMediaAppBackendService {
	
	/**
     * updateMediaAppStatus:(修改媒体应用信息状态). <br/>
     *
     * @author ZFZ
     * @param param
     * @return
     * @since JDK 1.6
     */
    DubboResult<MediaAppDto> updateMediaAppStatus(ReqUpdateMediaAppStatusDto param);

    /**
     * updateMediaWhitelistStatus:(修改媒体应用白名单状态). <br/>
     *
     * @author ZFZ
     * @param param
     * @return
     * @since JDK 1.6
     */
    Integer updateMediaAppWhitelistStatus(ReqUpdateMediaAppStatusDto param);


    DubboResult<Boolean> updateCheckMediaLinkStatus(ReqUpdateMediaAppStatusDto param);

    /**
     * updateMediaAppStatus:(修改媒体应用信息验证状态). <br/>
     *
     * @author ZFZ
     * @param param
     * @return
     * @since JDK 1.6
     */
    DubboResult<Integer> updateMediaAppVerifyStatus(ReqUpdateMediaAppVerifyStatusDto verifyStatusDto);

    /**
     * getMediaApp:(查看媒体应用信息状态). <br/>
     *
     * @author ZFZ
     * @param appId
     * @return
     * @since JDK 1.6
     */
    DubboResult<MediaAppDto> getMediaApp(Long appId);

    /**
     * 删除媒体应用ID和名称缓存.
     *
     * @return the dubbo result< boolean>
     */
    DubboResult<Boolean> delAllAppIdAndName();

    /**
     * 更具媒体应用名称模糊查询媒体应用ID.
     *
     * @param name the name
     * @return the app ids by name
     */
    DubboResult<List<Long>> getAppIdsByName(String name);

    /**
     * 通过媒体ID查询媒体名称.
     *
     * @param appId the app id
     * @return the app name by id
     */
    DubboResult<String> getAppNameById(Long appId);

    /**
     * 根据媒体ID列表查询媒体
     * 
     * @param ids
     * @return 媒体列表
     */
    DubboResult<List<MediaAppDto>> getMediaAppByIds(List<Long> ids);

    /**
     * getMediaAppCacheById:(通过媒体ID查询媒体信息). <br/>
     *
     * @param mediaId
     * @return
     * @since JDK 1.6
     */
    DubboResult<MediaAppDataDto> getMediaAppCacheById(Long mediaId);
    
    /**
     * 
     * 通过媒体App 名称查询媒体app list
     *
     * @author guyan
     * @param appName
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<MediaAppDto>> getMediaAppListByName(String appName);
    
    
    /**
     * 通过mediaIds查询appIds
     * @param mediaIds
     * @return
     */
    DubboResult<List<IdAndNameDto>> selectAppIdsByMediaIds(List<Long> mediaIds);
    
    /**
     * 
     * 修改媒体冻结状态
     *
     * @author guyan
     * @param param
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> updateAppFrozenStatus(ReqUpdateMediaAppStatusDto param);


    /**
     * 根据媒体ID列表查询媒体
     *
     * @param appIds
     * @return 媒体列表
     */
    List<MediaAppDto> selectAppInfoByAppIds(List<Long> appIds);

    Long getAnyoneAppId(Long mediaId);

    /**
     * 获取广告位
     * 手动投放链接
     * @param id
     * @return
     */
    String getActivityUrlById(Long id);

    /**
     * 获取下拉框list
     * @param req
     * @return
     */
    List<MediaSelectDto> getSelectMediaIdAndName(ReqMediaSelectDto req);

    /**
     * @Description 全量app详情获取
     * @Date 16:43 2020-06-12
     * @Param []
     * @return java.util.List<cn.com.duiba.tuia.ssp.center.api.dto.MediaAppDto>
     **/
    List<MediaAppDto> getAll();

    Boolean updateOrderIocnOnoff(ReqUpdateMediaAppStatusDto param);
}

==> ssp-center-api-1.1.74-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteMediaAppBackendService.java <==
/**
 * Project Name:media-api File Name:RemoteMediaAppService.java Package Name:cn.com.duiba.tuia.media.api.remoteservice
 * Date:2016年9月30日下午3:48:58 Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 */

package cn.com.duiba.tuia.ssp.center.api.remote;

import java.util.List;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.*;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName:RemoteMediaAppService <br/>
 * Function: tuia媒体app信息服务. <br/>
 * Date: 2016年9月30日 下午3:48:58 <br/>
 *
 * @author guyan
 * @version
 * @since JDK 1.6
 * @see
 */
@AdvancedFeignClient
public interface RemoteMediaAppBackendService {

	/**
     * updateMediaAppStatus:(修改媒体应用信息状态). <br/>
     *
     * @author ZFZ
     * @param param
     * @return
     * @since JDK 1.6
     */
    DubboResult<MediaAppDto> updateMediaAppStatus(ReqUpdateMediaAppStatusDto param);

    /**
     * updateMediaWhitelistStatus:(修改媒体应用白名单状态). <br/>
     *
     * @author ZFZ
     * @param param
     * @return
     * @since JDK 1.6
     */
    Integer updateMediaAppWhitelistStatus(ReqUpdateMediaAppStatusDto param);


    DubboResult<Boolean> updateCheckMediaLinkStatus(ReqUpdateMediaAppStatusDto param);

    /**
     * updateMediaAppStatus:(修改媒体应用信息验证状态). <br/>
     *
     * @author ZFZ
     * @param param
     * @return
     * @since JDK 1.6
     */
    DubboResult<Integer> updateMediaAppVerifyStatus(ReqUpdateMediaAppVerifyStatusDto verifyStatusDto);

    /**
     * getMediaApp:(查看媒体应用信息状态). <br/>
     *
     * @author ZFZ
     * @param appId
     * @return
     * @since JDK 1.6
     */
    DubboResult<MediaAppDto> getMediaApp(Long appId);

    /**
     * 删除媒体应用ID和名称缓存.
     *
     * @return the dubbo result< boolean>
     */
    DubboResult<Boolean> delAllAppIdAndName();

    /**
     * 更具媒体应用名称模糊查询媒体应用ID.
     *
     * @param name the name
     * @return the app ids by name
     */
    DubboResult<List<Long>> getAppIdsByName(String name);

    /**
     * 通过媒体ID查询媒体名称.
     *
     * @param appId the app id
     * @return the app name by id
     */
    DubboResult<String> getAppNameById(Long appId);

    /**
     * 根据媒体ID列表查询媒体
     *
     * @param ids
     * @return 媒体列表
     */
    DubboResult<List<MediaAppDto>> getMediaAppByIds(List<Long> ids);

    /**
     * getMediaAppCacheById:(通过媒体ID查询媒体信息). <br/>
     *
     * @param mediaId
     * @return
     * @since JDK 1.6
     */
    DubboResult<MediaAppDataDto> getMediaAppCacheById(Long mediaId);

    /**
     *
     * 通过媒体App 名称查询媒体app list
     *
     * @author guyan
     * @param appName
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<MediaAppDto>> getMediaAppListByName(String appName);


    /**
     * 通过mediaIds查询appIds
     * @param mediaIds
     * @return
     */
    DubboResult<List<IdAndNameDto>> selectAppIdsByMediaIds(List<Long> mediaIds);

    /**
     * 通过mediaIds和subMediaIds查询appIds
     * @param mediaIds
     * @return
     */
    DubboResult<List<IdAndNameDto>> selectAppIdsByMediaIdsAndSubMediaIds(List<Long> mediaIds);

    DubboResult<List<IdAndNameDto>> selectAppIdsByMediaIdsAndNonSubMediaId(List<Long> mediaIds);

    /**
     *
     * 修改媒体冻结状态
     *
     * @author guyan
     * @param param
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> updateAppFrozenStatus(ReqUpdateMediaAppStatusDto param);


    /**
     * 根据媒体ID列表查询媒体
     *
     * @param appIds
     * @return 媒体列表
     */
    List<MediaAppDto> selectAppInfoByAppIds(List<Long> appIds);

    Long getAnyoneAppId(Long mediaId);

    /**
     * 获取广告位
     * 手动投放链接
     * @param id
     * @return
     */
    String getActivityUrlById(Long id);

    /**
     * 获取广告位链接 不获取短链
     * @param slotId
     * @return
     */
    String getActivityLongUrlById(Long slotId);

    /**
     * 获取下拉框list
     * @param req
     * @return
     */
    List<MediaSelectDto> getSelectMediaIdAndName(ReqMediaSelectDto req);

    /**
     * @Description 全量app详情获取
     * @Date 16:43 2020-06-12
     * @Param []
     * @return java.util.List<cn.com.duiba.tuia.ssp.center.api.dto.MediaAppDto>
     **/
    List<MediaAppDto> getAll();

    Boolean updateOrderIocnOnoff(ReqUpdateMediaAppStatusDto param);


    /**
     * 模糊匹配 { APP.Id, APP.Name } 查询信息
     * @param characters 匹配字符
     * @return 处理结果
     */
    List<IdAndNameDto> fuzzySelectInfo(String characters);

    /**
     * 通过广告位ID
     * 获取广告位的投放真实链接和防封链接
     *
     * @param id
     * @return
     */
    DubboResult<BidGetActivityUrlDto> getActivityRealUrlById(Long id);

}
